@@ -29,11 +29,6 @@ describe 'aodh' do
         is_expected.to contain_aodh_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_password').with_value('<SERVICE DEFAULT>').with_secret(true)
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_userid').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
@@ -55,16 +50,11 @@ describe 'aodh' do
         {
           :debug                              => true,
           :default_transport_url              => 'rabbit://rabbit_user:password@localhost:5673',
-          :rabbit_host                        => 'rabbit',
-          :rabbit_userid                      => 'rabbit_user',
-          :rabbit_port                        => '5673',
-          :rabbit_password                    => 'password',
           :rabbit_ha_queues                   => 'undef',
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
           :kombu_compression                  => 'gzip',
           :package_ensure                     => '2012.1.1-15.el6',
-          :gnocchi_url                        => 'http://127.0.0.1:8041',
           :notification_transport_url         => 'rabbit://rabbit_user:password@localhost:5673',
           :notification_driver                => 'ceilometer.compute.aodh_notifier',
           :notification_topics                => 'openstack',
@@ -74,11 +64,6 @@ describe 'aodh' do
 
       it 'configures rabbit' do
         is_expected.to contain_aodh_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_host').with_value('rabbit')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_password').with_value('password').with_secret(true)
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_port').with_value('5673')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_userid').with_value('rabbit_user')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('60')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/heartbeat_rate').with_value('10')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_compression').with_value('gzip')
@@ -89,7 +74,6 @@ describe 'aodh' do
         is_expected.to contain_aodh_config('oslo_messaging_notifications/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
         is_expected.to contain_aodh_config('oslo_messaging_notifications/driver').with_value('ceilometer.compute.aodh_notifier')
         is_expected.to contain_aodh_config('oslo_messaging_notifications/topics').with_value('openstack')
-        is_expected.to contain_aodh_config('DEFAULT/gnocchi_url').with_value('http://127.0.0.1:8041')
       end
 
       context 'with multiple notification_driver' do
@@ -102,51 +86,15 @@ describe 'aodh' do
 
     end
 
-    context 'with rabbit_hosts parameter' do
+    context 'with kombu_reconnect_delay set to 5.0 and kombu_failover_strategy' do
       let :params do
-        { :rabbit_hosts => ['rabbit:5673', 'rabbit2:5674'] }
-      end
-
-      it 'configures rabbit' do
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_hosts').with_value('rabbit:5673,rabbit2:5674')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(true)
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_oslo__messaging__rabbit('aodh_config').with(
-          :rabbit_use_ssl => '<SERVICE DEFAULT>',
-        )
-      end
-    end
-
-    context 'with rabbit_hosts parameter (one server)' do
-      let :params do
-        { :rabbit_hosts => ['rabbit:5673'] }
-      end
-
-      it 'configures rabbit' do
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_hosts').with_value('rabbit:5673')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_oslo__messaging__rabbit('aodh_config').with(
-          :rabbit_use_ssl => '<SERVICE DEFAULT>',
-        )
-      end
-    end
-
-    context 'with kombu_reconnect_delay set to 5.0' do
-      let :params do
-        { :kombu_reconnect_delay => '5.0' }
+        { :kombu_reconnect_delay   => '5.0',
+          :kombu_failover_strategy => 'test' }
       end
 
       it 'configures rabbit' do
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('5.0')
+        is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('test')
       end
     end
 
@@ -160,10 +108,9 @@ describe 'aodh' do
       end
     end
 
-    context 'with rabbit_ha_queues set to false and with rabbit_hosts' do
+    context 'with rabbit_ha_queues set to false' do
       let :params do
-        { :rabbit_ha_queues => 'false',
-          :rabbit_hosts => ['rabbit:5673'] }
+        { :rabbit_ha_queues => 'false' }
       end
 
       it 'configures rabbit' do
@@ -173,14 +120,10 @@ describe 'aodh' do
 
     context 'with amqp_durable_queues parameter' do
       let :params do
-        { :rabbit_hosts => ['rabbit:5673'],
-          :amqp_durable_queues => 'true' }
+        { :amqp_durable_queues => 'true' }
       end
 
       it 'configures rabbit' do
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_hosts').with_value('rabbit:5673')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(true)
         is_expected.to contain_oslo__messaging__rabbit('aodh_config').with(
@@ -191,8 +134,7 @@ describe 'aodh' do
 
     context 'with rabbit ssl enabled with kombu' do
       let :params do
-        { :rabbit_hosts       => ['rabbit:5673'],
-          :rabbit_use_ssl     => true,
+        { :rabbit_use_ssl     => true,
           :kombu_ssl_ca_certs => '/etc/ca.cert',
           :kombu_ssl_certfile => '/etc/certfile',
           :kombu_ssl_keyfile  => '/etc/key',
@@ -210,12 +152,11 @@ describe 'aodh' do
 
     context 'with rabbit ssl enabled without kombu' do
       let :params do
-        { :rabbit_hosts       => ['rabbit:5673'],
-          :rabbit_use_ssl     => true, }
+        { :rabbit_use_ssl => true, }
       end
 
       it { is_expected.to contain_oslo__messaging__rabbit('aodh_config').with(
-        :rabbit_use_ssl     => true,
+        :rabbit_use_ssl => true,
       )}
     end
 
